@@ -20,8 +20,14 @@ import java.math.BigInteger;
 
 import net.morilib.lisp.sos.LispType;
 
+/**
+ * 
+ *
+ *
+ * @author MORIGUCHI, Yuichiro 2009
+ */
 public abstract class LispNumber extends Atom {
-	
+
 	/*package*/ static String disp(double n) {
 		if(n == Double.POSITIVE_INFINITY) {
 			return "+inf.0";
@@ -33,21 +39,21 @@ public abstract class LispNumber extends Atom {
 			return Double.toString(n);
 		}
 	}
-	
-	
+
+	//
 	private static enum State {
-		INIT,                           // 
-		NUMBER_PREFIX,                  // ͤprefix
-		HEAD_SIGN,                      // Ƭ
-		NUMBER,                         // 
-		FLOAT_NUMBER,                   // ư
-		FLOAT_NUMBER_D,                 // ư
-		FLOAT_NUMBER_E,                 // ưؿ
-		FLOAT_NUMBER_E_SIGN,            // ưؿ
-		FLOAT_NUMBER_E_D,               // ưؿ
-		RATIONAL_NUMBER,                // ͭ
-		RATIONAL_NUMBER_2,              // ͭ
-		INF_I,                          // ̵
+		INIT,                           // 初期状態
+		NUMBER_PREFIX,                  // 数値のprefix
+		HEAD_SIGN,                      // 先頭の符号
+		NUMBER,                         // 整数
+		FLOAT_NUMBER,                   // 浮動小数点開始
+		FLOAT_NUMBER_D,                 // 浮動小数点
+		FLOAT_NUMBER_E,                 // 浮動小数点指数部開始
+		FLOAT_NUMBER_E_SIGN,            // 浮動小数点指数部符号
+		FLOAT_NUMBER_E_D,               // 浮動小数点指数部
+		RATIONAL_NUMBER,                // 有理数開始
+		RATIONAL_NUMBER_2,              // 有理数
+		INF_I,                          // 無限
 		INF_N,
 		INF_F,
 		INF_DOT,
@@ -57,40 +63,40 @@ public abstract class LispNumber extends Atom {
 		NAN_N2,
 		NAN_DOT,
 		NAN_0,
-		COMPLEX_I,                      // 
-		INIT_POLAR,                     // (˷)
-		HEAD_SIGN_POLAR,                // Ƭ(˷)
-		NUMBER_POLAR,                   // (˷)
-		FLOAT_NUMBER_POLAR,             // ư(˷)
-		FLOAT_NUMBER_D_POLAR,           // ư(˷)
-		FLOAT_NUMBER_E_POLAR,           // ưؿ(˷)
-		FLOAT_NUMBER_E_SIGN_POLAR,      // ưؿ(˷)
-		FLOAT_NUMBER_E_D_POLAR,         // ưؿ(˷)
-		RATIONAL_NUMBER_POLAR,          // ͭ(˷)
-		RATIONAL_NUMBER_2_POLAR,        // ͭ(˷)
-		HEAD_SIGN_COMPLEX,              // Ƭ(ʣǿ)
-		NUMBER_COMPLEX,                 // (ʣǿ)
-		FLOAT_NUMBER_COMPLEX,           // ư(ʣǿ)
-		FLOAT_NUMBER_D_COMPLEX,         // ư(ʣǿ)
-		FLOAT_NUMBER_E_COMPLEX,         // ưؿ(ʣǿ)
-		FLOAT_NUMBER_E_SIGN_COMPLEX,    // ưؿ(ʣǿ)
-		FLOAT_NUMBER_E_D_COMPLEX,       // ưؿ(ʣǿ)
-		RATIONAL_NUMBER_COMPLEX,        // ͭ(ʣǿ)
-		RATIONAL_NUMBER_2_COMPLEX,      // ͭ(ʣǿ)
-		INF_I_COMPLEX,                  // ̵(ʣǿ)
+		COMPLEX_I,                      // 純虚数
+		INIT_POLAR,                     // 初期状態(極形式)
+		HEAD_SIGN_POLAR,                // 先頭の符号(極形式)
+		NUMBER_POLAR,                   // 整数(極形式)
+		FLOAT_NUMBER_POLAR,             // 浮動小数点開始(極形式)
+		FLOAT_NUMBER_D_POLAR,           // 浮動小数点(極形式)
+		FLOAT_NUMBER_E_POLAR,           // 浮動小数点指数部開始(極形式)
+		FLOAT_NUMBER_E_SIGN_POLAR,      // 浮動小数点指数部符号(極形式)
+		FLOAT_NUMBER_E_D_POLAR,         // 浮動小数点指数部(極形式)
+		RATIONAL_NUMBER_POLAR,          // 有理数開始(極形式)
+		RATIONAL_NUMBER_2_POLAR,        // 有理数(極形式)
+		HEAD_SIGN_COMPLEX,              // 先頭の符号(複素数)
+		NUMBER_COMPLEX,                 // 整数(複素数)
+		FLOAT_NUMBER_COMPLEX,           // 浮動小数点開始(複素数)
+		FLOAT_NUMBER_D_COMPLEX,         // 浮動小数点(複素数)
+		FLOAT_NUMBER_E_COMPLEX,         // 浮動小数点指数部開始(複素数)
+		FLOAT_NUMBER_E_SIGN_COMPLEX,    // 浮動小数点指数部符号(複素数)
+		FLOAT_NUMBER_E_D_COMPLEX,       // 浮動小数点指数部(複素数)
+		RATIONAL_NUMBER_COMPLEX,        // 有理数開始(複素数)
+		RATIONAL_NUMBER_2_COMPLEX,      // 有理数(複素数)
+		INF_I_COMPLEX,                  // 無限(複素数)
 		INF_N_COMPLEX,
 		INF_F_COMPLEX,
 		INF_DOT_COMPLEX,
 		INF_0_COMPLEX,
-		COMPLEX_I2,                     // ʣǿñ(i)
+		COMPLEX_I2,                     // 複素数単位(i)
 	};
-	
+
 	private enum Exact {
 		DEFAULT,
 		EXACT,
 		INEXACT,
 	}
-	
+
 	private static boolean isAlnum(int r, int radix) {
 		if(radix <= 10) {
 			return (r >= '0' && r <= '9');
@@ -102,11 +108,11 @@ public abstract class LispNumber extends Atom {
 					(r >= 'a' && r <= 'f') || (r >= 'A' && r <= 'F'));
 		}
 	}
-	
+
 	private static int read(String s, int p) {
 		return (p >= s.length()) ? -1 : s.charAt(p);
 	}
-	
+
 	private static double parseDouble(String str) {
 		if("+inf.0".equals(str)) {
 			return Double.POSITIVE_INFINITY;
@@ -120,15 +126,15 @@ public abstract class LispNumber extends Atom {
 			return Double.parseDouble(str);
 		}
 	}
-	
+
 	private static double getValueByDouble(String str) {
 		double i;
 		String[] ind = str.split("/");
-		
+
 		if(ind.length == 2) {
 			double n = parseDouble(ind[0]);
 			double d = parseDouble(ind[1]);
-			
+
 			i = n / d;
 		} else if(ind.length == 1) {
 			i = parseDouble(ind[0]);
@@ -137,16 +143,16 @@ public abstract class LispNumber extends Atom {
 		}
 		return i;
 	}
-	
+
 	private static BigInteger getValueByBigInt(String str, int r) {
 		return new BigInteger(str.replaceFirst("^\\+", ""), r);
 	}
-	
+
 	private static LispNumber getInteger(
 			String str, int radix, Exact exact) {
 		BigInteger num;
 		LispInteger li;
-		
+
 		try {
 			num = getValueByBigInt(str, radix);
 			li  = LispInteger.valueOf(num);
@@ -155,13 +161,13 @@ public abstract class LispNumber extends Atom {
 			return null;
 		}
 	}
-	
+
 	private static LispNumber getRational(
 			String str, int radix, Exact exact) {
 		String[] nd = str.split("/");
 		BigInteger num, den;
 		LispNumber li;
-		
+
 		try {
 			num = getValueByBigInt(nd[0], radix);
 			den = getValueByBigInt(nd[1], radix);
@@ -171,18 +177,18 @@ public abstract class LispNumber extends Atom {
 			return null;
 		}
 	}
-	
+
 	private static LispNumber getDouble(
 			String str, int radix, Exact ex) {
 		double val;
 		LispDouble atom;
 		int r = (radix < 0) ? 10 : radix;
-		
+
 		if(r != 10) {
 			return null;
 			//throw new ReadException("only radix 10 is supported");
 		}
-		
+
 		val = parseDouble(str);
 		atom = new LispDouble(val);
 		if(Exact.EXACT.equals(ex)) {
@@ -191,19 +197,19 @@ public abstract class LispNumber extends Atom {
 			return atom;
 		}
 	}
-	
+
 	private static LispNumber getImaginary(
 			String gtok1, int radix, Exact exact) {
-		// 
+		// 虚部
 		double i;
 		String   iii = gtok1.replaceFirst("i$", "");
-		
+
 		if(radix != 10) {
 			return null;
 		} else if(Exact.EXACT.equals(exact)) {
 			return null;
 		}
-		
+
 		if("+".equals(iii)) {
 			i = 1.0;
 		} else if("-".equals(iii)) {
@@ -211,22 +217,22 @@ public abstract class LispNumber extends Atom {
 		} else {
 			i = getValueByDouble(iii);
 		}
-		
+
 		return LispComplex.newComplex(0.0, i);
 	}
-	
+
 	private static LispNumber getComplex(
 			String gtok1, String gtok2, int radix, Exact exact) {
-		// 
+		// 虚部
 		double i;
 		String   iii = gtok2.replaceFirst("i$", "");
-		
+
 		if(radix != 10) {
 			return null;
 		} else if(Exact.EXACT.equals(exact)) {
 			return null;
 		}
-		
+
 		if("+".equals(iii)) {
 			i = 1.0;
 		} else if("-".equals(iii)) {
@@ -234,59 +240,65 @@ public abstract class LispNumber extends Atom {
 		} else {
 			i = getValueByDouble(iii);
 		}
-		
+
 		if(i != 0.0) {
-			// 
+			// 実部
 			double r = getValueByDouble(gtok1);
-			
+
 			return LispComplex.newComplex(r, i);
 		} else {
 			if(gtok1.indexOf('/') > 0) {
-				// ͭ
+				// 有理数
 				String[] nd = gtok1.split("/");
 				BigInteger num = new BigInteger(nd[0]);
 				BigInteger den = new BigInteger(nd[1]);
-				
+
 				return LispRational.newRational(num, den);
 			} else if(gtok1.matches("^[0-9]+$")) {
-				// 
+				// 整数
 				BigInteger  val  = new BigInteger(gtok1);
 				LispInteger atom = LispInteger.valueOf(val);
-				
+
 				return atom;
 			} else {
-				// ư
+				// 浮動小数点数
 				double val = parseDouble(gtok1);
 				LispDouble atom = new LispDouble(val);
-				
+
 				return atom;
 			}
 		}
 	}
-	
+
 	private static LispNumber getPolar(
 			String str, int radix, Exact exact) {
 		double r;
 		String[] ra = str.split("@");
-		
+
 		if(radix != 10) {
 			return null;
 		} else if(Exact.EXACT.equals(exact)) {
 			return null;
 		}
-		
-		r = getValueByDouble(ra[0]);    // Ⱦ
+
+		r = getValueByDouble(ra[0]);    // 半径
 		if(r == 0.0) {
 			return new LispDouble(0.0);
 		} else {
 			double a = getValueByDouble(ra[1]);
-			
+
 			return LispComplex.newComplex(
 					r * Math.cos(a),
 					r * Math.sin(a));
 		}
 	}
-	
+
+	/**
+	 * 
+	 * @param s
+	 * @param radix
+	 * @return
+	 */
 	public static LispNumber parse(String s, int radix) {
 		StringBuilder b1 = new StringBuilder();
 		StringBuilder b2 = new StringBuilder();
@@ -296,11 +308,11 @@ public abstract class LispNumber extends Atom {
 		boolean signed = false;
 		int p = 0;
 		int r = read(s, p);
-		
+
 		if(radix < 1 || radix > 16) {
 			throw new IllegalArgumentException("wrong radix");
 		}
-		
+
 		while(true) {
 			switch(state) {
 			case INIT:
@@ -329,7 +341,7 @@ public abstract class LispNumber extends Atom {
 					return null;
 				} else if(r == '#') {
 					r = read(s, ++p);
-					
+
 					if(r == 'e' || r == 'E') {
 						if(!Exact.DEFAULT.equals(exact)) {
 							return null;
@@ -394,7 +406,7 @@ public abstract class LispNumber extends Atom {
 				break;
 			case HEAD_SIGN:
 				signed = true;
-				
+
 				if(isAlnum(r, radix)) {
 					state = State.NUMBER;
 				} else if(r == '.') {
@@ -737,7 +749,7 @@ public abstract class LispNumber extends Atom {
 			case INF_0:
 				if(r < 0) {
 					String s1 = b1.toString();
-					
+
 					if(s1.charAt(0) == '+') {
 						return LispDouble.POSITIVE_INFINITY;
 					} else {
@@ -1003,88 +1015,169 @@ public abstract class LispNumber extends Atom {
 			}
 		}
 	}
-	
-	
+
+	/**
+	 * 
+	 * @param x
+	 * @return
+	 */
 	public abstract LispNumber add(LispNumber x);
-	
-	
+
+	/**
+	 * 
+	 * @param x
+	 * @return
+	 */
 	public abstract LispNumber sub(LispNumber x);
-	
-	
+
+	/**
+	 * 
+	 * @param x
+	 * @return
+	 */
 	public abstract LispNumber mul(LispNumber x);
-	
-	
+
+	/**
+	 * 
+	 * @param x
+	 * @return
+	 */
 	public abstract LispNumber div(LispNumber x);
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract LispNumber uminus();
-	
-	
+
+	/**
+	 * 
+	 * @param x
+	 * @return
+	 */
 	public abstract boolean isEqualTo(LispNumber x);
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract boolean isInteger();
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract boolean isRational();
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract boolean isReal();
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract boolean isExact();
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract LispNumber toExact();
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract LispNumber toInexact();
-	
-	
+
+	/**
+	 * 
+	 * @param radix
+	 * @return
+	 */
 	public abstract LispString toLispString(int radix);
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract boolean isNaN();
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract boolean isOne();
-	
-	
+
+	/*
+	 * (non-Javadoc)
+	 * @see net.morilib.lisp.Datum#getInt()
+	 */
 	public abstract int getInt();
-	
-	
+
+	/*
+	 * (non-Javadoc)
+	 * @see net.morilib.lisp.Datum#getLong()
+	 */
 	public abstract long getLong();
-	
-	
+
+	/*
+	 * (non-Javadoc)
+	 * @see net.morilib.lisp.Datum#getBigInteger()
+	 */
 	public abstract BigInteger getBigInteger();
-	
-	
+
+	/*
+	 * (non-Javadoc)
+	 * @see net.morilib.lisp.Datum#getBigDecimal()
+	 */
 	public abstract BigDecimal getBigDecimal();
-	
-	
+
+	/*
+	 * (non-Javadoc)
+	 * @see net.morilib.lisp.Datum#getRealDouble()
+	 */
 	public abstract double getRealDouble();
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract BigInteger getNumerator();
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public abstract BigInteger getDenominator();
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public int getExactSmallInt() {
 		throw new NumberFormatException();
 	}
-	
-	
+
+	/*
+	 * (non-Javadoc)
+	 * @see net.morilib.lisp.Atom#toLispString()
+	 */
 	public LispString toLispString() {
 		return toLispString(10);
 	}
-	
-	
+
+	/**
+	 * 
+	 * @return
+	 */
 	public boolean isZero() {
 		return isEqualTo(LispInteger.ZERO);
 	}
-	
+
 	/* (non-Javadoc)
 	 * @see net.morilib.lisp.Datum#getType()
 	 */
@@ -1092,5 +1185,5 @@ public abstract class LispNumber extends Atom {
 	public LispType getType() {
 		return LispType.NUMBER;
 	}
-	
+
 }
